var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { defaultProps } from '../../DayPicker';
import { getPrevNextMonths } from './getPrevNextMonths';
describe('getPrevNextMonths', function () {
    it('return next and previous months with default props', function () {
        var _a = getPrevNextMonths(defaultProps), prevMonth = _a[0], nextMonth = _a[1];
        expect(nextMonth).toBeDefined();
        expect(prevMonth).toBeDefined();
    });
    it('defaults to current month', function () {
        var _a = getPrevNextMonths(__assign({}, defaultProps)), prevMonth = _a[0], nextMonth = _a[1];
        expect(nextMonth).toBeDefined();
        expect(prevMonth).toBeDefined();
    });
    it('return next and previous months for the specified month', function () {
        var _a = getPrevNextMonths(__assign(__assign({}, defaultProps), { month: new Date(2019, 8) })), prevMonth = _a[0], nextMonth = _a[1];
        expect(nextMonth && nextMonth.getMonth()).toBe(9);
        expect(prevMonth && prevMonth.getMonth()).toBe(7);
    });
    it('respect the passed number of months', function () {
        var _a = getPrevNextMonths(__assign(__assign({}, defaultProps), { month: new Date(2019, 8), pagedNavigation: true, numberOfMonths: 3 })), prevMonth = _a[0], nextMonth = _a[1];
        expect(nextMonth && nextMonth.getMonth()).toBe(11);
        expect(prevMonth && prevMonth.getMonth()).toBe(5);
    });
    it('returns undefined as prev month when fromMonth is set', function () {
        var prevMonth = getPrevNextMonths(__assign(__assign({}, defaultProps), { month: new Date(2019, 8), fromMonth: new Date(2019, 8) }))[0];
        expect(prevMonth).toBeUndefined();
    });
    it('returns undefined as next month when toMonth is set', function () {
        var _a = getPrevNextMonths(__assign(__assign({}, defaultProps), { month: new Date(2019, 8), toMonth: new Date(2019, 8) })), nextMonth = _a[1];
        expect(nextMonth).toBeUndefined();
    });
});
//# sourceMappingURL=getPrevNextMonths.test.js.map