import { addMonths, differenceInMonths, startOfMonth } from 'date-fns';
/**
 * Get the months to render in DayPicker according to the passed
 * `numberOfMonths` and other month-related props.
 */
export function getMonths(props) {
    var month = props.month, numberOfMonths = props.numberOfMonths, toMonth = props.toMonth, fromMonth = props.fromMonth, reverseMonths = props.reverseMonths;
    var start = startOfMonth(month);
    var end = startOfMonth(addMonths(start, numberOfMonths));
    var monthsDiff = differenceInMonths(end, start);
    var months = [];
    for (var i = 0; i < monthsDiff; i++) {
        var nextMonth = addMonths(start, i);
        if (toMonth && nextMonth > startOfMonth(toMonth)) {
            // Skip months after toMonth
            continue;
        }
        if (fromMonth && nextMonth < startOfMonth(fromMonth)) {
            // Skip months before fromMonth
            continue;
        }
        months.push(nextMonth);
    }
    if (reverseMonths) {
        months = months.reverse();
    }
    return months;
}
//# sourceMappingURL=getMonths.js.map