import { useState } from 'react';
import { addToRange } from './addToRange';
var emptyRange = { from: undefined, to: undefined };
/**
 * Returns a range and a state setter for handing ranges when selecting dates.
 *
 * **Example**
 *
 * ```jsx showOutput open=false
 * function Example() {
 *   const [range, setRange] = useRange();
 *   return <DayPicker onDayClick={setRange} selected={range} />;
 * }
 * ```
 */
export function useRange(initialRange) {
    if (initialRange === void 0) { initialRange = emptyRange; }
    var _a = useState(initialRange), range = _a[0], setInternalRange = _a[1];
    var setRange = function (day) {
        if (!day) {
            setInternalRange(emptyRange);
        }
        else {
            setInternalRange(addToRange(range, day));
        }
        return;
    };
    return [range, setRange];
}
//# sourceMappingURL=useRange.js.map